import { s as subscribe, i as identity, a as assign, g as get_store_value, n as noop } from './utils-CddEWsFi.js';
import { c as create_ssr_component, e as escape, a as add_attribute, b as each, v as validate_component, m as missing_component } from './ssr-zF9v48TM.js';
import { U as UserLink } from './UserLink-C3MlKD0D.js';
import { u as userData } from './firebase-C_9MAyfc.js';
import 'firebase/auth';
import './client-CjdeEz1m.js';
import { w as writable } from './index2-CGXXJYvl.js';
import 'firebase/app';
import 'firebase/firestore';
import 'firebase/storage';
import './exports-DuWZopOC.js';

const is_client = typeof window !== "undefined";
let now = is_client ? () => window.performance.now() : () => Date.now();
let raf = is_client ? (cb) => requestAnimationFrame(cb) : noop;
const tasks = /* @__PURE__ */ new Set();
function run_tasks(now2) {
  tasks.forEach((task) => {
    if (!task.c(now2)) {
      tasks.delete(task);
      task.f();
    }
  });
  if (tasks.size !== 0)
    raf(run_tasks);
}
function loop(callback) {
  let task;
  if (tasks.size === 0)
    raf(run_tasks);
  return {
    promise: new Promise((fulfill) => {
      tasks.add(task = { c: callback, f: fulfill });
    }),
    abort() {
      tasks.delete(task);
    }
  };
}
function notificationsStore(initialValue = []) {
  const store = writable(initialValue);
  const { set, update, subscribe: subscribe2 } = store;
  let defaultOptions = {
    duration: 3e3,
    placement: "bottom-right",
    type: "info",
    theme: "dark"
  };
  function add(options) {
    const {
      duration = 3e3,
      placement = "bottom-right",
      type = "info",
      theme = "dark",
      ...rest
    } = { ...defaultOptions, ...options };
    const uid = Date.now();
    const obj = {
      ...rest,
      uid,
      placement,
      type,
      theme,
      duration,
      remove: () => {
        update((v) => v.filter((i) => i.uid !== uid));
      },
      update: (data) => {
        delete data.uid;
        const index = get_store_value(store)?.findIndex((v) => v?.uid === uid);
        if (index > -1) {
          update((v) => [
            ...v.slice(0, index),
            { ...v[index], ...data },
            ...v.slice(index + 1)
          ]);
        }
      }
    };
    update((v) => [...v, obj]);
    if (duration > 0) {
      setTimeout(() => {
        obj.remove();
        if (typeof obj.onRemove === "function")
          obj.onRemove();
      }, duration);
    }
    return obj;
  }
  function getById(uid) {
    return get_store_value(store)?.find((v) => v?.uid === uid);
  }
  function clearAll() {
    set([]);
  }
  function clearLast() {
    update((v) => {
      return v.slice(0, v.length - 1);
    });
  }
  function setDefaults(options) {
    defaultOptions = { ...defaultOptions, ...options };
  }
  return {
    subscribe: subscribe2,
    add,
    success: getHelper("success", add),
    info: getHelper("info", add),
    error: getHelper("error", add),
    warning: getHelper("warning", add),
    clearAll,
    clearLast,
    getById,
    setDefaults
  };
}
const toasts = notificationsStore([]);
function getHelper(type, add) {
  return function() {
    if (typeof arguments[0] === "object") {
      const options = arguments[0];
      return add({ ...options, type });
    } else if (typeof arguments[0] === "string" && typeof arguments[1] === "string") {
      const options = arguments[2] || {};
      return add({
        ...options,
        type,
        title: arguments[0],
        description: arguments[1]
      });
    } else if (typeof arguments[0] === "string") {
      const options = arguments[1] || {};
      return add({
        ...options,
        type,
        description: arguments[0]
      });
    }
  };
}
const css$1 = {
  code: "ul.svelte-s8abgz.svelte-s8abgz{list-style:none;margin:0;padding:0}li.svelte-s8abgz.svelte-s8abgz{display:flex;justify-content:space-between;align-items:center;margin-bottom:10px}.toast-container.svelte-s8abgz.svelte-s8abgz{z-index:9999;position:fixed;padding:4px;box-sizing:border-box;color:#fff;width:-moz-max-content;width:max-content;max-width:100%;pointer-events:none}.toast-container.bottom-right.svelte-s8abgz.svelte-s8abgz{bottom:1em;right:1em}.toast-container.bottom-left.svelte-s8abgz.svelte-s8abgz{bottom:1em;left:1em}.toast-container.top-left.svelte-s8abgz.svelte-s8abgz{top:1em;left:1em}.toast-container.top-right.svelte-s8abgz.svelte-s8abgz{top:1em;right:1em}.toast-container.top-center.svelte-s8abgz.svelte-s8abgz{top:1em;right:50%;left:50%;transform:translate(-50%, 0)}.toast-container.bottom-center.svelte-s8abgz.svelte-s8abgz{bottom:1em;right:50%;left:50%;transform:translate(-50%, 0)}.toast-container.center-center.svelte-s8abgz.svelte-s8abgz{top:50%;right:50%;left:50%;transform:translate(-50%, -50%)}.toast-container.svelte-s8abgz>.svelte-s8abgz:not(:last-child){margin-bottom:10px}",
  map: `{"version":3,"file":"ToastContainer.svelte","sources":["ToastContainer.svelte"],"sourcesContent":["<script>\\n  import { fly, fade } from 'svelte/transition';\\n  import { onMount } from 'svelte';\\n  import { flip } from 'svelte/animate';\\n  import toasts from './toasts';\\n\\n  /**\\n   * @typedef {'success' | 'info' | 'error' | 'warning'} ToastType\\n   * @typedef {'bottom-right' | 'bottom-left' | 'top-right' | 'top-left' | 'top-center' | 'bottom-center' | 'center-center'} Placement\\n   * @typedef {{\\n      uid: number;\\n      title?: string;\\n      description: string;\\n      duration: number;\\n      type: ToastType;\\n      theme?: Theme;\\n      placement: Placement;\\n      showProgress?: boolean;\\n      remove?: Function;\\n      update?: Function;\\n      onRemove?: Function;\\n      onClick?: Function;\\n    }} ToastProps\\n   */\\n\\n  /**\\n   * Default theme for all toasts\\n   * @type { Theme }\\n   */\\n  export let theme = 'dark';\\n\\n  /**\\n   * Default placement for all toasts\\n   * @type { Placement }\\n   */\\n  export let placement = 'bottom-right';\\n\\n  /**\\n   * Default type of all toasts\\n   * @type { ToastType }\\n   */\\n  export let type = 'info';\\n\\n  /**\\n   * Show progress if showProgress is true and duration is greater then 0\\n   * @type { boolean }\\n   */\\n  export let showProgress = false;\\n  /**\\n   * Default duration for all toasts to auto close. 0 to disable auto close\\n   * @type { number }\\n   */\\n  export let duration = 3000;\\n  /**\\n   * Width of all toasts\\n   * @type { string }\\n   */\\n  export let width = '320px';\\n\\n  /**\\n   * Default slot which is Toast component/template which will get toast data\\n   * @slot {{ data: ToastProps }}\\n   */\\n\\n  const placements = [\\n    'bottom-right',\\n    'bottom-left',\\n    'top-right',\\n    'top-left',\\n    'top-center',\\n    'bottom-center',\\n    'center-center',\\n  ];\\n  const flyMap = {\\n    'bottom-right': 400,\\n    'top-right': -400,\\n    'bottom-left': 400,\\n    'top-left': -400,\\n    'bottom-center': 400,\\n    'top-center': -400,\\n    'center-center': -800,\\n  };\\n  onMount(() => {\\n    toasts.setDefaults({\\n      placement,\\n      showProgress,\\n      theme,\\n      duration,\\n      type,\\n    });\\n  });\\n<\/script>\\n\\n{#each placements as placement}\\n  <div class=\\"toast-container {placement}\\" style=\\"width: {width}\\">\\n    <ul>\\n      {#each $toasts\\n        .filter((n) => n.placement === placement)\\n        .reverse() as toast (toast.uid)}\\n        <li\\n          animate:flip\\n          out:fly={{ y: flyMap[toast.placement], duration: 1000 }}\\n          in:fade={{ duration: 500 }}\\n        >\\n          {#if toast.component}\\n            <svelte:component this={toast.component} data={toast} />\\n          {:else}\\n            <slot data={toast} />\\n          {/if}\\n        </li>\\n      {/each}\\n    </ul>\\n  </div>\\n{/each}\\n\\n<style>\\n  ul {\\n    list-style: none;\\n    margin: 0;\\n    padding: 0;\\n  }\\n  li {\\n    display: flex;\\n    justify-content: space-between;\\n    align-items: center;\\n    margin-bottom: 10px;\\n  }\\n  .toast-container {\\n    z-index: 9999;\\n    position: fixed;\\n    padding: 4px;\\n    box-sizing: border-box;\\n    color: #fff;\\n    width: -moz-max-content;\\n    width: max-content;\\n    max-width: 100%;\\n    pointer-events: none;\\n  }\\n  .toast-container.bottom-right {\\n    bottom: 1em;\\n    right: 1em;\\n  }\\n  .toast-container.bottom-left {\\n    bottom: 1em;\\n    left: 1em;\\n  }\\n  .toast-container.top-left {\\n    top: 1em;\\n    left: 1em;\\n  }\\n  .toast-container.top-right {\\n    top: 1em;\\n    right: 1em;\\n  }\\n  .toast-container.top-center {\\n    top: 1em;\\n    right: 50%;\\n    left: 50%;\\n    transform: translate(-50%, 0);\\n  }\\n  .toast-container.bottom-center {\\n    bottom: 1em;\\n    right: 50%;\\n    left: 50%;\\n    transform: translate(-50%, 0);\\n  }\\n  .toast-container.center-center {\\n    top: 50%;\\n    right: 50%;\\n    left: 50%;\\n    transform: translate(-50%, -50%);\\n  }\\n  .toast-container > :not(:last-child) {\\n    margin-bottom: 10px;\\n  }\\n</style>\\n"],"names":[],"mappings":"AAoHE,8BAAG,CACD,UAAU,CAAE,IAAI,CAChB,MAAM,CAAE,CAAC,CACT,OAAO,CAAE,CACX,CACA,8BAAG,CACD,OAAO,CAAE,IAAI,CACb,eAAe,CAAE,aAAa,CAC9B,WAAW,CAAE,MAAM,CACnB,aAAa,CAAE,IACjB,CACA,4CAAiB,CACf,OAAO,CAAE,IAAI,CACb,QAAQ,CAAE,KAAK,CACf,OAAO,CAAE,GAAG,CACZ,UAAU,CAAE,UAAU,CACtB,KAAK,CAAE,IAAI,CACX,KAAK,CAAE,gBAAgB,CACvB,KAAK,CAAE,WAAW,CAClB,SAAS,CAAE,IAAI,CACf,cAAc,CAAE,IAClB,CACA,gBAAgB,yCAAc,CAC5B,MAAM,CAAE,GAAG,CACX,KAAK,CAAE,GACT,CACA,gBAAgB,wCAAa,CAC3B,MAAM,CAAE,GAAG,CACX,IAAI,CAAE,GACR,CACA,gBAAgB,qCAAU,CACxB,GAAG,CAAE,GAAG,CACR,IAAI,CAAE,GACR,CACA,gBAAgB,sCAAW,CACzB,GAAG,CAAE,GAAG,CACR,KAAK,CAAE,GACT,CACA,gBAAgB,uCAAY,CAC1B,GAAG,CAAE,GAAG,CACR,KAAK,CAAE,GAAG,CACV,IAAI,CAAE,GAAG,CACT,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,CAAC,CAC9B,CACA,gBAAgB,0CAAe,CAC7B,MAAM,CAAE,GAAG,CACX,KAAK,CAAE,GAAG,CACV,IAAI,CAAE,GAAG,CACT,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,CAAC,CAC9B,CACA,gBAAgB,0CAAe,CAC7B,GAAG,CAAE,GAAG,CACR,KAAK,CAAE,GAAG,CACV,IAAI,CAAE,GAAG,CACT,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,IAAI,CACjC,CACA,8BAAgB,eAAG,KAAK,WAAW,CAAE,CACnC,aAAa,CAAE,IACjB"}`
};
const ToastContainer = create_ssr_component(($$result, $$props, $$bindings, slots) => {
  let $toasts, $$unsubscribe_toasts;
  $$unsubscribe_toasts = subscribe(toasts, (value) => $toasts = value);
  let { theme = "dark" } = $$props;
  let { placement = "bottom-right" } = $$props;
  let { type = "info" } = $$props;
  let { showProgress = false } = $$props;
  let { duration = 3e3 } = $$props;
  let { width = "320px" } = $$props;
  const placements = [
    "bottom-right",
    "bottom-left",
    "top-right",
    "top-left",
    "top-center",
    "bottom-center",
    "center-center"
  ];
  if ($$props.theme === void 0 && $$bindings.theme && theme !== void 0)
    $$bindings.theme(theme);
  if ($$props.placement === void 0 && $$bindings.placement && placement !== void 0)
    $$bindings.placement(placement);
  if ($$props.type === void 0 && $$bindings.type && type !== void 0)
    $$bindings.type(type);
  if ($$props.showProgress === void 0 && $$bindings.showProgress && showProgress !== void 0)
    $$bindings.showProgress(showProgress);
  if ($$props.duration === void 0 && $$bindings.duration && duration !== void 0)
    $$bindings.duration(duration);
  if ($$props.width === void 0 && $$bindings.width && width !== void 0)
    $$bindings.width(width);
  $$result.css.add(css$1);
  $$unsubscribe_toasts();
  return `${each(placements, (placement2) => {
    return `<div class="${"toast-container " + escape(placement2, true) + " svelte-s8abgz"}" style="${"width: " + escape(width, true)}"><ul class="svelte-s8abgz">${each($toasts.filter((n) => n.placement === placement2).reverse(), (toast) => {
      return `<li class="svelte-s8abgz">${toast.component ? `${validate_component(toast.component || missing_component, "svelte:component").$$render($$result, { data: toast }, {}, {})}` : `${slots.default ? slots.default({ data: toast }) : ``}`} </li>`;
    })}</ul> </div>`;
  })}`;
});
function is_date(obj) {
  return Object.prototype.toString.call(obj) === "[object Date]";
}
function get_interpolator(a, b) {
  if (a === b || a !== a)
    return () => a;
  const type = typeof a;
  if (type !== typeof b || Array.isArray(a) !== Array.isArray(b)) {
    throw new Error("Cannot interpolate values of different type");
  }
  if (Array.isArray(a)) {
    const arr = b.map((bi, i) => {
      return get_interpolator(a[i], bi);
    });
    return (t) => arr.map((fn) => fn(t));
  }
  if (type === "object") {
    if (!a || !b)
      throw new Error("Object cannot be null");
    if (is_date(a) && is_date(b)) {
      a = a.getTime();
      b = b.getTime();
      const delta = b - a;
      return (t) => new Date(a + t * delta);
    }
    const keys = Object.keys(b);
    const interpolators = {};
    keys.forEach((key) => {
      interpolators[key] = get_interpolator(a[key], b[key]);
    });
    return (t) => {
      const result = {};
      keys.forEach((key) => {
        result[key] = interpolators[key](t);
      });
      return result;
    };
  }
  if (type === "number") {
    const delta = b - a;
    return (t) => a + t * delta;
  }
  throw new Error(`Cannot interpolate ${type} values`);
}
function tweened(value, defaults = {}) {
  const store = writable(value);
  let task;
  let target_value = value;
  function set(new_value, opts) {
    if (value == null) {
      store.set(value = new_value);
      return Promise.resolve();
    }
    target_value = new_value;
    let previous_task = task;
    let started = false;
    let {
      delay = 0,
      duration = 400,
      easing = identity,
      interpolate = get_interpolator
    } = assign(assign({}, defaults), opts);
    if (duration === 0) {
      if (previous_task) {
        previous_task.abort();
        previous_task = null;
      }
      store.set(value = target_value);
      return Promise.resolve();
    }
    const start = now() + delay;
    let fn;
    task = loop((now2) => {
      if (now2 < start)
        return true;
      if (!started) {
        fn = interpolate(value, new_value);
        if (typeof duration === "function")
          duration = duration(value, new_value);
        started = true;
      }
      if (previous_task) {
        previous_task.abort();
        previous_task = null;
      }
      const elapsed = now2 - start;
      if (elapsed > /** @type {number} */
      duration) {
        store.set(value = new_value);
        return false;
      }
      store.set(value = fn(easing(elapsed / duration)));
      return true;
    });
    return task.promise;
  }
  return {
    set,
    update: (fn, opts) => set(fn(target_value, value), opts),
    subscribe: store.subscribe
  };
}
const css = {
  code: ".st-toast.svelte-uiy59d.svelte-uiy59d{display:flex;pointer-events:auto;width:320px;height:auto;padding-left:0.875rem;color:#fff;box-shadow:0 2px 6px 0 rgba(0, 0, 0, 0.2);position:relative;cursor:pointer}.st-toast.svelte-uiy59d .st-toast-icon.svelte-uiy59d{flex-shrink:0;margin-right:0.875rem;margin-top:0.875rem}.st-toast.svelte-uiy59d progress[value].svelte-uiy59d{-webkit-appearance:none;-moz-appearance:none;appearance:none;display:block;width:100%;position:absolute;bottom:0;left:0;right:0;height:4px}.st-toast.dark.svelte-uiy59d.svelte-uiy59d{color:#fff;background:#393939}.st-toast.dark.svelte-uiy59d progress[value].svelte-uiy59d::-webkit-progress-bar{background-color:#393939}.st-toast.dark.svelte-uiy59d .st-toast-close-btn svg.svelte-uiy59d{fill:#fff}.st-toast.dark.svelte-uiy59d .st-toast-close-btn.svelte-uiy59d:focus{border:solid 1px #fff}.st-toast.dark.success.svelte-uiy59d.svelte-uiy59d{border-left:3px solid rgb(22, 163, 74)}.st-toast.dark.success.svelte-uiy59d .st-toast-icon.svelte-uiy59d{fill:rgb(22, 163, 74);color:#fff}.st-toast.dark.success.svelte-uiy59d progress[value].svelte-uiy59d::-webkit-progress-value{background-color:rgb(22, 163, 74)}.st-toast.dark.info.svelte-uiy59d.svelte-uiy59d{border-left:3px solid rgb(2, 132, 199)}.st-toast.dark.info.svelte-uiy59d .st-toast-icon.svelte-uiy59d{fill:rgb(2, 132, 199);color:#fff}.st-toast.dark.info.svelte-uiy59d progress[value].svelte-uiy59d::-webkit-progress-value{background-color:rgb(2, 132, 199)}.st-toast.dark.error.svelte-uiy59d.svelte-uiy59d{border-left:3px solid rgb(225, 29, 72)}.st-toast.dark.error.svelte-uiy59d .st-toast-icon.svelte-uiy59d{fill:rgb(225, 29, 72);color:#fff}.st-toast.dark.error.svelte-uiy59d progress[value].svelte-uiy59d::-webkit-progress-value{background-color:rgb(225, 29, 72)}.st-toast.dark.warning.svelte-uiy59d.svelte-uiy59d{border-left:3px solid rgb(202, 138, 4)}.st-toast.dark.warning.svelte-uiy59d .st-toast-icon.svelte-uiy59d{fill:rgb(202, 138, 4);color:#fff}.st-toast.dark.warning.svelte-uiy59d progress[value].svelte-uiy59d::-webkit-progress-value{background-color:rgb(202, 138, 4)}.st-toast.light.svelte-uiy59d.svelte-uiy59d{color:#161616;fill:#161616}.st-toast.light.success.svelte-uiy59d.svelte-uiy59d{border-left:3px solid rgb(22, 163, 74);background:rgba(22, 163, 74, 0.2)}.st-toast.light.success.svelte-uiy59d progress.svelte-uiy59d{background:rgba(22, 163, 74, 0.2)}.st-toast.light.success.svelte-uiy59d progress[value].svelte-uiy59d::-webkit-progress-bar{background-color:transparent}.st-toast.light.success.svelte-uiy59d progress[value].svelte-uiy59d::-webkit-progress-value{background-color:rgb(22, 163, 74)}.st-toast.light.success.svelte-uiy59d .st-toast-icon.svelte-uiy59d{fill:rgb(22, 163, 74)}.st-toast.light.success.svelte-uiy59d .st-toast-close-btn.svelte-uiy59d:focus{border:solid 1px rgb(22, 163, 74)}.st-toast.light.success.svelte-uiy59d.svelte-uiy59d::before{border-color:rgb(22, 163, 74);content:'';pointer-events:none;position:absolute;top:0;left:0;width:100%;height:100%;box-sizing:border-box;filter:opacity(0.4);border-style:solid;border-width:1px 1px 1px 0}.st-toast.light.info.svelte-uiy59d.svelte-uiy59d{border-left:3px solid rgb(2, 132, 199);background:rgba(2, 132, 199, 0.2)}.st-toast.light.info.svelte-uiy59d progress.svelte-uiy59d{background:rgba(2, 132, 199, 0.2)}.st-toast.light.info.svelte-uiy59d progress[value].svelte-uiy59d::-webkit-progress-bar{background-color:transparent}.st-toast.light.info.svelte-uiy59d progress[value].svelte-uiy59d::-webkit-progress-value{background-color:rgb(2, 132, 199)}.st-toast.light.info.svelte-uiy59d .st-toast-icon.svelte-uiy59d{fill:rgb(2, 132, 199)}.st-toast.light.info.svelte-uiy59d .st-toast-close-btn.svelte-uiy59d:focus{border:solid 1px rgb(2, 132, 199)}.st-toast.light.info.svelte-uiy59d.svelte-uiy59d::before{border-color:rgb(2, 132, 199);content:'';pointer-events:none;position:absolute;top:0;left:0;width:100%;height:100%;box-sizing:border-box;filter:opacity(0.4);border-style:solid;border-width:1px 1px 1px 0}.st-toast.light.error.svelte-uiy59d.svelte-uiy59d{border-left:3px solid rgb(225, 29, 72);background:rgba(225, 29, 72, 0.2)}.st-toast.light.error.svelte-uiy59d progress.svelte-uiy59d{background:rgba(225, 29, 72, 0.2)}.st-toast.light.error.svelte-uiy59d progress[value].svelte-uiy59d::-webkit-progress-bar{background-color:transparent}.st-toast.light.error.svelte-uiy59d progress[value].svelte-uiy59d::-webkit-progress-value{background-color:rgb(225, 29, 72)}.st-toast.light.error.svelte-uiy59d .st-toast-icon.svelte-uiy59d{fill:rgb(225, 29, 72)}.st-toast.light.error.svelte-uiy59d .st-toast-close-btn.svelte-uiy59d:focus{border:solid 1px rgb(225, 29, 72)}.st-toast.light.error.svelte-uiy59d.svelte-uiy59d::before{border-color:rgb(225, 29, 72);content:'';pointer-events:none;position:absolute;top:0;left:0;width:100%;height:100%;box-sizing:border-box;filter:opacity(0.4);border-style:solid;border-width:1px 1px 1px 0}.st-toast.light.warning.svelte-uiy59d.svelte-uiy59d{border-left:3px solid rgb(202, 138, 4);background:rgba(202, 138, 4, 0.2)}.st-toast.light.warning.svelte-uiy59d progress.svelte-uiy59d{background:rgba(202, 138, 4, 0.2)}.st-toast.light.warning.svelte-uiy59d progress[value].svelte-uiy59d::-webkit-progress-bar{background-color:transparent}.st-toast.light.warning.svelte-uiy59d progress[value].svelte-uiy59d::-webkit-progress-value{background-color:rgb(202, 138, 4)}.st-toast.light.warning.svelte-uiy59d .st-toast-icon.svelte-uiy59d{fill:rgb(202, 138, 4)}.st-toast.light.warning.svelte-uiy59d .st-toast-close-btn.svelte-uiy59d:focus{border:solid 1px rgb(202, 138, 4)}.st-toast.light.warning.svelte-uiy59d.svelte-uiy59d::before{border-color:rgb(202, 138, 4);content:'';pointer-events:none;position:absolute;top:0;left:0;width:100%;height:100%;box-sizing:border-box;filter:opacity(0.4);border-style:solid;border-width:1px 1px 1px 0}.st-toast-details.svelte-uiy59d.svelte-uiy59d{margin-top:0.875rem;margin-right:1rem;text-align:left;align-self:flex-start}.st-toast-details.svelte-uiy59d .st-toast-title.svelte-uiy59d{font-size:0.875rem;line-height:1.125rem;letter-spacing:0.16px;font-weight:600;word-break:break-word;margin:0;outline:none}.st-toast-details.svelte-uiy59d .st-toast-description.svelte-uiy59d{font-size:0.875rem;font-weight:400;line-height:1.125rem;letter-spacing:0.16px;margin-top:0;margin-bottom:1rem;word-break:break-word}.st-toast-close-btn.svelte-uiy59d.svelte-uiy59d{outline:2px solid transparent;outline-offset:-2px;display:flex;align-items:center;justify-content:center;background-color:transparent;border:none;cursor:pointer;margin-left:auto;padding:0;height:3rem;width:3rem;min-height:3rem;min-width:3rem;transition:outline 110ms, background-color 110ms}",
  map: `{"version":3,"file":"FlatToast.svelte","sources":["FlatToast.svelte"],"sourcesContent":["<script>\\n  import { onMount } from 'svelte';\\n  import { tweened } from 'svelte/motion';\\n  import { linear } from 'svelte/easing';\\n\\n  /**\\n   * Default theme for all toasts\\n   * @type { Theme }\\n   */\\n  export let theme = 'light';\\n\\n  /**\\n   * Default theme for all toasts\\n   * @type { ToastProps }\\n   */\\n  export let data = {};\\n\\n  const progress = tweened(1, {\\n    duration: data.duration,\\n    easing: linear,\\n  });\\n\\n  onMount(() => {\\n    progress.set(0, { duration: data.duration });\\n  });\\n\\n  const onRemove = (e) => {\\n    e.stopPropagation();\\n    data.remove();\\n    if (typeof data.onRemove === 'function') data.onRemove();\\n  };\\n  const onClick = () => {\\n    if (typeof data.onClick === 'function') data.onClick();\\n  };\\n<\/script>\\n\\n<div\\n  class=\\"st-toast flat {data.theme || theme} {data.type || 'info'}\\"\\n  on:click={onClick}\\n  role=\\"alert\\"\\n  aria-live=\\"assertive\\"\\n  aria-atomic=\\"true\\"\\n>\\n  <slot name=\\"icon\\">\\n    {#if data.type === 'success'}\\n      <svg\\n        class=\\"st-toast-icon\\"\\n        xmlns=\\"http://www.w3.org/2000/svg\\"\\n        width=\\"20\\"\\n        height=\\"20\\"\\n        viewBox=\\"0 0 20 20\\"\\n        aria-hidden=\\"true\\"\\n      >\\n        <path\\n          d=\\"M10,1c-4.9,0-9,4.1-9,9s4.1,9,9,9s9-4,9-9S15,1,10,1z M8.7,13.5l-3.2-3.2l1-1l2.2,2.2l4.8-4.8l1,1L8.7,13.5z\\"\\n        />\\n        <path\\n          fill=\\"none\\"\\n          d=\\"M8.7,13.5l-3.2-3.2l1-1l2.2,2.2l4.8-4.8l1,1L8.7,13.5z\\"\\n          data-icon-path=\\"inner-path\\"\\n          opacity=\\"0\\"\\n        />\\n      </svg>\\n    {:else if data.type === 'info'}\\n      <svg\\n        class=\\"st-toast-icon\\"\\n        xmlns=\\"http://www.w3.org/2000/svg\\"\\n        width=\\"20\\"\\n        height=\\"20\\"\\n        viewBox=\\"0 0 32 32\\"\\n        aria-hidden=\\"true\\"\\n        ><path\\n          d=\\"M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,5a1.5,1.5,0,1,1-1.5,1.5A1.5,1.5,0,0,1,16,7Zm4,17.12H12V21.88h2.88V15.12H13V12.88h4.13v9H20Z\\"\\n        /></svg\\n      >\\n    {:else if data.type === 'error'}\\n      <svg\\n        class=\\"st-toast-icon\\"\\n        xmlns=\\"http://www.w3.org/2000/svg\\"\\n        width=\\"20\\"\\n        height=\\"20\\"\\n        viewBox=\\"0 0 20 20\\"\\n        aria-hidden=\\"true\\"\\n        ><path\\n          d=\\"M10,1c-5,0-9,4-9,9s4,9,9,9s9-4,9-9S15,1,10,1z M13.5,14.5l-8-8l1-1l8,8L13.5,14.5z\\"\\n        /><path\\n          d=\\"M13.5,14.5l-8-8l1-1l8,8L13.5,14.5z\\"\\n          data-icon-path=\\"inner-path\\"\\n          opacity=\\"0\\"\\n        /></svg\\n      >\\n    {:else}\\n      <svg\\n        class=\\"st-toast-icon\\"\\n        xmlns=\\"http://www.w3.org/2000/svg\\"\\n        width=\\"20\\"\\n        height=\\"20\\"\\n        viewBox=\\"0 0 20 20\\"\\n        aria-hidden=\\"true\\"\\n        ><path\\n          d=\\"M10,1c-5,0-9,4-9,9s4,9,9,9s9-4,9-9S15,1,10,1z M9.2,5h1.5v7H9.2V5z M10,16c-0.6,0-1-0.4-1-1s0.4-1,1-1\\ts1,0.4,1,1S10.6,16,10,16z\\"\\n        /><path\\n          d=\\"M9.2,5h1.5v7H9.2V5z M10,16c-0.6,0-1-0.4-1-1s0.4-1,1-1s1,0.4,1,1S10.6,16,10,16z\\"\\n          data-icon-path=\\"inner-path\\"\\n          opacity=\\"0\\"\\n        /></svg\\n      >\\n    {/if}\\n  </slot>\\n\\n  <div class=\\"st-toast-details\\">\\n    {#if data.title}\\n      <h3 class=\\"st-toast-title\\">{data.title}</h3>\\n    {/if}\\n\\n    <p class=\\"st-toast-description\\">{data.description}</p>\\n    <div class=\\"st-toast-extra\\">\\n      <slot name=\\"extra\\" />\\n    </div>\\n  </div>\\n  <button\\n    class=\\"st-toast-close-btn\\"\\n    type=\\"button\\"\\n    aria-label=\\"close\\"\\n    on:click={onRemove}\\n  >\\n    <slot name=\\"close-icon\\">\\n      <svg\\n        xmlns=\\"http://www.w3.org/2000/svg\\"\\n        class=\\"bx--toast-notification__close-icon\\"\\n        width=\\"20\\"\\n        height=\\"20\\"\\n        viewBox=\\"0 0 32 32\\"\\n        aria-hidden=\\"true\\"\\n      >\\n        <path\\n          d=\\"M24 9.4L22.6 8 16 14.6 9.4 8 8 9.4 14.6 16 8 22.6 9.4 24 16 17.4 22.6 24 24 22.6 17.4 16 24 9.4z\\"\\n        />\\n      </svg>\\n    </slot>\\n  </button>\\n  {#if data.showProgress}\\n    <progress\\n      style=\\"height: {data.duration > 0 ? '4px' : 0}\\"\\n      value={$progress}\\n    />\\n  {/if}\\n</div>\\n\\n<style>\\n  .st-toast {\\n    display: flex;\\n    pointer-events: auto;\\n    width: 320px;\\n    height: auto;\\n    padding-left: 0.875rem;\\n    color: #fff;\\n    box-shadow: 0 2px 6px 0 rgba(0, 0, 0, 0.2);\\n    position: relative;\\n    cursor: pointer;\\n  }\\n  .st-toast .st-toast-icon {\\n    flex-shrink: 0;\\n    margin-right: 0.875rem;\\n    margin-top: 0.875rem;\\n  }\\n  .st-toast progress[value] {\\n    -webkit-appearance: none;\\n       -moz-appearance: none;\\n            appearance: none;\\n    display: block;\\n    width: 100%;\\n    position: absolute;\\n    bottom: 0;\\n    left: 0;\\n    right: 0;\\n    height: 4px;\\n  }\\n  .st-toast.dark {\\n    color: #fff;\\n    background: #393939;\\n  }\\n  .st-toast.dark progress[value]::-webkit-progress-bar {\\n    background-color: #393939;\\n  }\\n  .st-toast.dark .st-toast-close-btn svg {\\n    fill: #fff;\\n  }\\n  .st-toast.dark .st-toast-close-btn:focus {\\n    border: solid 1px #fff;\\n  }\\n  .st-toast.dark.success {\\n    border-left: 3px solid rgb(22, 163, 74);\\n  }\\n  .st-toast.dark.success .st-toast-icon {\\n    fill: rgb(22, 163, 74);\\n    color: #fff;\\n  }\\n  .st-toast.dark.success progress[value]::-webkit-progress-value {\\n    background-color: rgb(22, 163, 74);\\n  }\\n  .st-toast.dark.info {\\n    border-left: 3px solid rgb(2, 132, 199);\\n  }\\n  .st-toast.dark.info .st-toast-icon {\\n    fill: rgb(2, 132, 199);\\n    color: #fff;\\n  }\\n  .st-toast.dark.info progress[value]::-webkit-progress-value {\\n    background-color: rgb(2, 132, 199);\\n  }\\n  .st-toast.dark.error {\\n    border-left: 3px solid rgb(225, 29, 72);\\n  }\\n  .st-toast.dark.error .st-toast-icon {\\n    fill: rgb(225, 29, 72);\\n    color: #fff;\\n  }\\n  .st-toast.dark.error progress[value]::-webkit-progress-value {\\n    background-color: rgb(225, 29, 72);\\n  }\\n  .st-toast.dark.warning {\\n    border-left: 3px solid rgb(202, 138, 4);\\n  }\\n  .st-toast.dark.warning .st-toast-icon {\\n    fill: rgb(202, 138, 4);\\n    color: #fff;\\n  }\\n  .st-toast.dark.warning progress[value]::-webkit-progress-value {\\n    background-color: rgb(202, 138, 4);\\n  }\\n  .st-toast.light {\\n    color: #161616;\\n    fill: #161616;\\n  }\\n  .st-toast.light.success {\\n    border-left: 3px solid rgb(22, 163, 74);\\n    background: rgba(22, 163, 74, 0.2);\\n  }\\n  .st-toast.light.success progress {\\n    background: rgba(22, 163, 74, 0.2);\\n  }\\n  .st-toast.light.success progress[value]::-webkit-progress-bar {\\n    background-color: transparent;\\n  }\\n  .st-toast.light.success progress[value]::-webkit-progress-value {\\n    background-color: rgb(22, 163, 74);\\n  }\\n  .st-toast.light.success .st-toast-icon {\\n    fill: rgb(22, 163, 74);\\n  }\\n  .st-toast.light.success .st-toast-close-btn:focus {\\n    border: solid 1px rgb(22, 163, 74);\\n  }\\n  .st-toast.light.success::before {\\n    border-color: rgb(22, 163, 74);\\n    content: '';\\n    pointer-events: none;\\n    position: absolute;\\n    top: 0;\\n    left: 0;\\n    width: 100%;\\n    height: 100%;\\n    box-sizing: border-box;\\n    filter: opacity(0.4);\\n    border-style: solid;\\n    border-width: 1px 1px 1px 0;\\n  }\\n  .st-toast.light.info {\\n    border-left: 3px solid rgb(2, 132, 199);\\n    background: rgba(2, 132, 199, 0.2);\\n  }\\n  .st-toast.light.info progress {\\n    background: rgba(2, 132, 199, 0.2);\\n  }\\n  .st-toast.light.info progress[value]::-webkit-progress-bar {\\n    background-color: transparent;\\n  }\\n  .st-toast.light.info progress[value]::-webkit-progress-value {\\n    background-color: rgb(2, 132, 199);\\n  }\\n  .st-toast.light.info .st-toast-icon {\\n    fill: rgb(2, 132, 199);\\n  }\\n  .st-toast.light.info .st-toast-close-btn:focus {\\n    border: solid 1px rgb(2, 132, 199);\\n  }\\n  .st-toast.light.info::before {\\n    border-color: rgb(2, 132, 199);\\n    content: '';\\n    pointer-events: none;\\n    position: absolute;\\n    top: 0;\\n    left: 0;\\n    width: 100%;\\n    height: 100%;\\n    box-sizing: border-box;\\n    filter: opacity(0.4);\\n    border-style: solid;\\n    border-width: 1px 1px 1px 0;\\n  }\\n  .st-toast.light.error {\\n    border-left: 3px solid rgb(225, 29, 72);\\n    background: rgba(225, 29, 72, 0.2);\\n  }\\n  .st-toast.light.error progress {\\n    background: rgba(225, 29, 72, 0.2);\\n  }\\n  .st-toast.light.error progress[value]::-webkit-progress-bar {\\n    background-color: transparent;\\n  }\\n  .st-toast.light.error progress[value]::-webkit-progress-value {\\n    background-color: rgb(225, 29, 72);\\n  }\\n  .st-toast.light.error .st-toast-icon {\\n    fill: rgb(225, 29, 72);\\n  }\\n  .st-toast.light.error .st-toast-close-btn:focus {\\n    border: solid 1px rgb(225, 29, 72);\\n  }\\n  .st-toast.light.error::before {\\n    border-color: rgb(225, 29, 72);\\n    content: '';\\n    pointer-events: none;\\n    position: absolute;\\n    top: 0;\\n    left: 0;\\n    width: 100%;\\n    height: 100%;\\n    box-sizing: border-box;\\n    filter: opacity(0.4);\\n    border-style: solid;\\n    border-width: 1px 1px 1px 0;\\n  }\\n  .st-toast.light.warning {\\n    border-left: 3px solid rgb(202, 138, 4);\\n    background: rgba(202, 138, 4, 0.2);\\n  }\\n  .st-toast.light.warning progress {\\n    background: rgba(202, 138, 4, 0.2);\\n  }\\n  .st-toast.light.warning progress[value]::-webkit-progress-bar {\\n    background-color: transparent;\\n  }\\n  .st-toast.light.warning progress[value]::-webkit-progress-value {\\n    background-color: rgb(202, 138, 4);\\n  }\\n  .st-toast.light.warning .st-toast-icon {\\n    fill: rgb(202, 138, 4);\\n  }\\n  .st-toast.light.warning .st-toast-close-btn:focus {\\n    border: solid 1px rgb(202, 138, 4);\\n  }\\n  .st-toast.light.warning::before {\\n    border-color: rgb(202, 138, 4);\\n    content: '';\\n    pointer-events: none;\\n    position: absolute;\\n    top: 0;\\n    left: 0;\\n    width: 100%;\\n    height: 100%;\\n    box-sizing: border-box;\\n    filter: opacity(0.4);\\n    border-style: solid;\\n    border-width: 1px 1px 1px 0;\\n  }\\n  .st-toast-details {\\n    margin-top: 0.875rem;\\n    margin-right: 1rem;\\n    text-align: left;\\n    align-self: flex-start;\\n  }\\n  .st-toast-details .st-toast-title {\\n    font-size: 0.875rem;\\n    line-height: 1.125rem;\\n    letter-spacing: 0.16px;\\n    font-weight: 600;\\n    word-break: break-word;\\n    margin: 0;\\n    outline: none;\\n  }\\n  .st-toast-details .st-toast-description {\\n    font-size: 0.875rem;\\n    font-weight: 400;\\n    line-height: 1.125rem;\\n    letter-spacing: 0.16px;\\n    margin-top: 0;\\n    margin-bottom: 1rem;\\n    word-break: break-word;\\n  }\\n  .st-toast-close-btn {\\n    outline: 2px solid transparent;\\n    outline-offset: -2px;\\n    display: flex;\\n    align-items: center;\\n    justify-content: center;\\n    background-color: transparent;\\n    border: none;\\n    cursor: pointer;\\n    margin-left: auto;\\n    padding: 0;\\n    height: 3rem;\\n    width: 3rem;\\n    min-height: 3rem;\\n    min-width: 3rem;\\n    transition: outline 110ms, background-color 110ms;\\n  }\\n</style>\\n"],"names":[],"mappings":"AAsJE,qCAAU,CACR,OAAO,CAAE,IAAI,CACb,cAAc,CAAE,IAAI,CACpB,KAAK,CAAE,KAAK,CACZ,MAAM,CAAE,IAAI,CACZ,YAAY,CAAE,QAAQ,CACtB,KAAK,CAAE,IAAI,CACX,UAAU,CAAE,CAAC,CAAC,GAAG,CAAC,GAAG,CAAC,CAAC,CAAC,KAAK,CAAC,CAAC,CAAC,CAAC,CAAC,CAAC,CAAC,CAAC,CAAC,GAAG,CAAC,CAC1C,QAAQ,CAAE,QAAQ,CAClB,MAAM,CAAE,OACV,CACA,uBAAS,CAAC,4BAAe,CACvB,WAAW,CAAE,CAAC,CACd,YAAY,CAAE,QAAQ,CACtB,UAAU,CAAE,QACd,CACA,uBAAS,CAAC,QAAQ,CAAC,KAAK,eAAE,CACxB,kBAAkB,CAAE,IAAI,CACrB,eAAe,CAAE,IAAI,CAChB,UAAU,CAAE,IAAI,CACxB,OAAO,CAAE,KAAK,CACd,KAAK,CAAE,IAAI,CACX,QAAQ,CAAE,QAAQ,CAClB,MAAM,CAAE,CAAC,CACT,IAAI,CAAE,CAAC,CACP,KAAK,CAAE,CAAC,CACR,MAAM,CAAE,GACV,CACA,SAAS,iCAAM,CACb,KAAK,CAAE,IAAI,CACX,UAAU,CAAE,OACd,CACA,SAAS,mBAAK,CAAC,QAAQ,CAAC,KAAK,eAAC,sBAAuB,CACnD,gBAAgB,CAAE,OACpB,CACA,SAAS,mBAAK,CAAC,mBAAmB,CAAC,iBAAI,CACrC,IAAI,CAAE,IACR,CACA,SAAS,mBAAK,CAAC,iCAAmB,MAAO,CACvC,MAAM,CAAE,KAAK,CAAC,GAAG,CAAC,IACpB,CACA,SAAS,KAAK,oCAAS,CACrB,WAAW,CAAE,GAAG,CAAC,KAAK,CAAC,IAAI,EAAE,CAAC,CAAC,GAAG,CAAC,CAAC,EAAE,CACxC,CACA,SAAS,KAAK,sBAAQ,CAAC,4BAAe,CACpC,IAAI,CAAE,IAAI,EAAE,CAAC,CAAC,GAAG,CAAC,CAAC,EAAE,CAAC,CACtB,KAAK,CAAE,IACT,CACA,SAAS,KAAK,sBAAQ,CAAC,QAAQ,CAAC,KAAK,eAAC,wBAAyB,CAC7D,gBAAgB,CAAE,IAAI,EAAE,CAAC,CAAC,GAAG,CAAC,CAAC,EAAE,CACnC,CACA,SAAS,KAAK,iCAAM,CAClB,WAAW,CAAE,GAAG,CAAC,KAAK,CAAC,IAAI,CAAC,CAAC,CAAC,GAAG,CAAC,CAAC,GAAG,CACxC,CACA,SAAS,KAAK,mBAAK,CAAC,4BAAe,CACjC,IAAI,CAAE,IAAI,CAAC,CAAC,CAAC,GAAG,CAAC,CAAC,GAAG,CAAC,CACtB,KAAK,CAAE,IACT,CACA,SAAS,KAAK,mBAAK,CAAC,QAAQ,CAAC,KAAK,eAAC,wBAAyB,CAC1D,gBAAgB,CAAE,IAAI,CAAC,CAAC,CAAC,GAAG,CAAC,CAAC,GAAG,CACnC,CACA,SAAS,KAAK,kCAAO,CACnB,WAAW,CAAE,GAAG,CAAC,KAAK,CAAC,IAAI,GAAG,CAAC,CAAC,EAAE,CAAC,CAAC,EAAE,CACxC,CACA,SAAS,KAAK,oBAAM,CAAC,4BAAe,CAClC,IAAI,CAAE,IAAI,GAAG,CAAC,CAAC,EAAE,CAAC,CAAC,EAAE,CAAC,CACtB,KAAK,CAAE,IACT,CACA,SAAS,KAAK,oBAAM,CAAC,QAAQ,CAAC,KAAK,eAAC,wBAAyB,CAC3D,gBAAgB,CAAE,IAAI,GAAG,CAAC,CAAC,EAAE,CAAC,CAAC,EAAE,CACnC,CACA,SAAS,KAAK,oCAAS,CACrB,WAAW,CAAE,GAAG,CAAC,KAAK,CAAC,IAAI,GAAG,CAAC,CAAC,GAAG,CAAC,CAAC,CAAC,CACxC,CACA,SAAS,KAAK,sBAAQ,CAAC,4BAAe,CACpC,IAAI,CAAE,IAAI,GAAG,CAAC,CAAC,GAAG,CAAC,CAAC,CAAC,CAAC,CACtB,KAAK,CAAE,IACT,CACA,SAAS,KAAK,sBAAQ,CAAC,QAAQ,CAAC,KAAK,eAAC,wBAAyB,CAC7D,gBAAgB,CAAE,IAAI,GAAG,CAAC,CAAC,GAAG,CAAC,CAAC,CAAC,CACnC,CACA,SAAS,kCAAO,CACd,KAAK,CAAE,OAAO,CACd,IAAI,CAAE,OACR,CACA,SAAS,MAAM,oCAAS,CACtB,WAAW,CAAE,GAAG,CAAC,KAAK,CAAC,IAAI,EAAE,CAAC,CAAC,GAAG,CAAC,CAAC,EAAE,CAAC,CACvC,UAAU,CAAE,KAAK,EAAE,CAAC,CAAC,GAAG,CAAC,CAAC,EAAE,CAAC,CAAC,GAAG,CACnC,CACA,SAAS,MAAM,sBAAQ,CAAC,sBAAS,CAC/B,UAAU,CAAE,KAAK,EAAE,CAAC,CAAC,GAAG,CAAC,CAAC,EAAE,CAAC,CAAC,GAAG,CACnC,CACA,SAAS,MAAM,sBAAQ,CAAC,QAAQ,CAAC,KAAK,eAAC,sBAAuB,CAC5D,gBAAgB,CAAE,WACpB,CACA,SAAS,MAAM,sBAAQ,CAAC,QAAQ,CAAC,KAAK,eAAC,wBAAyB,CAC9D,gBAAgB,CAAE,IAAI,EAAE,CAAC,CAAC,GAAG,CAAC,CAAC,EAAE,CACnC,CACA,SAAS,MAAM,sBAAQ,CAAC,4BAAe,CACrC,IAAI,CAAE,IAAI,EAAE,CAAC,CAAC,GAAG,CAAC,CAAC,EAAE,CACvB,CACA,SAAS,MAAM,sBAAQ,CAAC,iCAAmB,MAAO,CAChD,MAAM,CAAE,KAAK,CAAC,GAAG,CAAC,IAAI,EAAE,CAAC,CAAC,GAAG,CAAC,CAAC,EAAE,CACnC,CACA,SAAS,MAAM,oCAAQ,QAAS,CAC9B,YAAY,CAAE,IAAI,EAAE,CAAC,CAAC,GAAG,CAAC,CAAC,EAAE,CAAC,CAC9B,OAAO,CAAE,EAAE,CACX,cAAc,CAAE,IAAI,CACpB,QAAQ,CAAE,QAAQ,CAClB,GAAG,CAAE,CAAC,CACN,IAAI,CAAE,CAAC,CACP,KAAK,CAAE,IAAI,CACX,MAAM,CAAE,IAAI,CACZ,UAAU,CAAE,UAAU,CACtB,MAAM,CAAE,QAAQ,GAAG,CAAC,CACpB,YAAY,CAAE,KAAK,CACnB,YAAY,CAAE,GAAG,CAAC,GAAG,CAAC,GAAG,CAAC,CAC5B,CACA,SAAS,MAAM,iCAAM,CACnB,WAAW,CAAE,GAAG,CAAC,KAAK,CAAC,IAAI,CAAC,CAAC,CAAC,GAAG,CAAC,CAAC,GAAG,CAAC,CACvC,UAAU,CAAE,KAAK,CAAC,CAAC,CAAC,GAAG,CAAC,CAAC,GAAG,CAAC,CAAC,GAAG,CACnC,CACA,SAAS,MAAM,mBAAK,CAAC,sBAAS,CAC5B,UAAU,CAAE,KAAK,CAAC,CAAC,CAAC,GAAG,CAAC,CAAC,GAAG,CAAC,CAAC,GAAG,CACnC,CACA,SAAS,MAAM,mBAAK,CAAC,QAAQ,CAAC,KAAK,eAAC,sBAAuB,CACzD,gBAAgB,CAAE,WACpB,CACA,SAAS,MAAM,mBAAK,CAAC,QAAQ,CAAC,KAAK,eAAC,wBAAyB,CAC3D,gBAAgB,CAAE,IAAI,CAAC,CAAC,CAAC,GAAG,CAAC,CAAC,GAAG,CACnC,CACA,SAAS,MAAM,mBAAK,CAAC,4BAAe,CAClC,IAAI,CAAE,IAAI,CAAC,CAAC,CAAC,GAAG,CAAC,CAAC,GAAG,CACvB,CACA,SAAS,MAAM,mBAAK,CAAC,iCAAmB,MAAO,CAC7C,MAAM,CAAE,KAAK,CAAC,GAAG,CAAC,IAAI,CAAC,CAAC,CAAC,GAAG,CAAC,CAAC,GAAG,CACnC,CACA,SAAS,MAAM,iCAAK,QAAS,CAC3B,YAAY,CAAE,IAAI,CAAC,CAAC,CAAC,GAAG,CAAC,CAAC,GAAG,CAAC,CAC9B,OAAO,CAAE,EAAE,CACX,cAAc,CAAE,IAAI,CACpB,QAAQ,CAAE,QAAQ,CAClB,GAAG,CAAE,CAAC,CACN,IAAI,CAAE,CAAC,CACP,KAAK,CAAE,IAAI,CACX,MAAM,CAAE,IAAI,CACZ,UAAU,CAAE,UAAU,CACtB,MAAM,CAAE,QAAQ,GAAG,CAAC,CACpB,YAAY,CAAE,KAAK,CACnB,YAAY,CAAE,GAAG,CAAC,GAAG,CAAC,GAAG,CAAC,CAC5B,CACA,SAAS,MAAM,kCAAO,CACpB,WAAW,CAAE,GAAG,CAAC,KAAK,CAAC,IAAI,GAAG,CAAC,CAAC,EAAE,CAAC,CAAC,EAAE,CAAC,CACvC,UAAU,CAAE,KAAK,GAAG,CAAC,CAAC,EAAE,CAAC,CAAC,EAAE,CAAC,CAAC,GAAG,CACnC,CACA,SAAS,MAAM,oBAAM,CAAC,sBAAS,CAC7B,UAAU,CAAE,KAAK,GAAG,CAAC,CAAC,EAAE,CAAC,CAAC,EAAE,CAAC,CAAC,GAAG,CACnC,CACA,SAAS,MAAM,oBAAM,CAAC,QAAQ,CAAC,KAAK,eAAC,sBAAuB,CAC1D,gBAAgB,CAAE,WACpB,CACA,SAAS,MAAM,oBAAM,CAAC,QAAQ,CAAC,KAAK,eAAC,wBAAyB,CAC5D,gBAAgB,CAAE,IAAI,GAAG,CAAC,CAAC,EAAE,CAAC,CAAC,EAAE,CACnC,CACA,SAAS,MAAM,oBAAM,CAAC,4BAAe,CACnC,IAAI,CAAE,IAAI,GAAG,CAAC,CAAC,EAAE,CAAC,CAAC,EAAE,CACvB,CACA,SAAS,MAAM,oBAAM,CAAC,iCAAmB,MAAO,CAC9C,MAAM,CAAE,KAAK,CAAC,GAAG,CAAC,IAAI,GAAG,CAAC,CAAC,EAAE,CAAC,CAAC,EAAE,CACnC,CACA,SAAS,MAAM,kCAAM,QAAS,CAC5B,YAAY,CAAE,IAAI,GAAG,CAAC,CAAC,EAAE,CAAC,CAAC,EAAE,CAAC,CAC9B,OAAO,CAAE,EAAE,CACX,cAAc,CAAE,IAAI,CACpB,QAAQ,CAAE,QAAQ,CAClB,GAAG,CAAE,CAAC,CACN,IAAI,CAAE,CAAC,CACP,KAAK,CAAE,IAAI,CACX,MAAM,CAAE,IAAI,CACZ,UAAU,CAAE,UAAU,CACtB,MAAM,CAAE,QAAQ,GAAG,CAAC,CACpB,YAAY,CAAE,KAAK,CACnB,YAAY,CAAE,GAAG,CAAC,GAAG,CAAC,GAAG,CAAC,CAC5B,CACA,SAAS,MAAM,oCAAS,CACtB,WAAW,CAAE,GAAG,CAAC,KAAK,CAAC,IAAI,GAAG,CAAC,CAAC,GAAG,CAAC,CAAC,CAAC,CAAC,CACvC,UAAU,CAAE,KAAK,GAAG,CAAC,CAAC,GAAG,CAAC,CAAC,CAAC,CAAC,CAAC,GAAG,CACnC,CACA,SAAS,MAAM,sBAAQ,CAAC,sBAAS,CAC/B,UAAU,CAAE,KAAK,GAAG,CAAC,CAAC,GAAG,CAAC,CAAC,CAAC,CAAC,CAAC,GAAG,CACnC,CACA,SAAS,MAAM,sBAAQ,CAAC,QAAQ,CAAC,KAAK,eAAC,sBAAuB,CAC5D,gBAAgB,CAAE,WACpB,CACA,SAAS,MAAM,sBAAQ,CAAC,QAAQ,CAAC,KAAK,eAAC,wBAAyB,CAC9D,gBAAgB,CAAE,IAAI,GAAG,CAAC,CAAC,GAAG,CAAC,CAAC,CAAC,CACnC,CACA,SAAS,MAAM,sBAAQ,CAAC,4BAAe,CACrC,IAAI,CAAE,IAAI,GAAG,CAAC,CAAC,GAAG,CAAC,CAAC,CAAC,CACvB,CACA,SAAS,MAAM,sBAAQ,CAAC,iCAAmB,MAAO,CAChD,MAAM,CAAE,KAAK,CAAC,GAAG,CAAC,IAAI,GAAG,CAAC,CAAC,GAAG,CAAC,CAAC,CAAC,CACnC,CACA,SAAS,MAAM,oCAAQ,QAAS,CAC9B,YAAY,CAAE,IAAI,GAAG,CAAC,CAAC,GAAG,CAAC,CAAC,CAAC,CAAC,CAC9B,OAAO,CAAE,EAAE,CACX,cAAc,CAAE,IAAI,CACpB,QAAQ,CAAE,QAAQ,CAClB,GAAG,CAAE,CAAC,CACN,IAAI,CAAE,CAAC,CACP,KAAK,CAAE,IAAI,CACX,MAAM,CAAE,IAAI,CACZ,UAAU,CAAE,UAAU,CACtB,MAAM,CAAE,QAAQ,GAAG,CAAC,CACpB,YAAY,CAAE,KAAK,CACnB,YAAY,CAAE,GAAG,CAAC,GAAG,CAAC,GAAG,CAAC,CAC5B,CACA,6CAAkB,CAChB,UAAU,CAAE,QAAQ,CACpB,YAAY,CAAE,IAAI,CAClB,UAAU,CAAE,IAAI,CAChB,UAAU,CAAE,UACd,CACA,+BAAiB,CAAC,6BAAgB,CAChC,SAAS,CAAE,QAAQ,CACnB,WAAW,CAAE,QAAQ,CACrB,cAAc,CAAE,MAAM,CACtB,WAAW,CAAE,GAAG,CAChB,UAAU,CAAE,UAAU,CACtB,MAAM,CAAE,CAAC,CACT,OAAO,CAAE,IACX,CACA,+BAAiB,CAAC,mCAAsB,CACtC,SAAS,CAAE,QAAQ,CACnB,WAAW,CAAE,GAAG,CAChB,WAAW,CAAE,QAAQ,CACrB,cAAc,CAAE,MAAM,CACtB,UAAU,CAAE,CAAC,CACb,aAAa,CAAE,IAAI,CACnB,UAAU,CAAE,UACd,CACA,+CAAoB,CAClB,OAAO,CAAE,GAAG,CAAC,KAAK,CAAC,WAAW,CAC9B,cAAc,CAAE,IAAI,CACpB,OAAO,CAAE,IAAI,CACb,WAAW,CAAE,MAAM,CACnB,eAAe,CAAE,MAAM,CACvB,gBAAgB,CAAE,WAAW,CAC7B,MAAM,CAAE,IAAI,CACZ,MAAM,CAAE,OAAO,CACf,WAAW,CAAE,IAAI,CACjB,OAAO,CAAE,CAAC,CACV,MAAM,CAAE,IAAI,CACZ,KAAK,CAAE,IAAI,CACX,UAAU,CAAE,IAAI,CAChB,SAAS,CAAE,IAAI,CACf,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,CAAC,gBAAgB,CAAC,KAC9C"}`
};
const FlatToast = create_ssr_component(($$result, $$props, $$bindings, slots) => {
  let $progress, $$unsubscribe_progress;
  let { theme = "light" } = $$props;
  let { data = {} } = $$props;
  const progress = tweened(1, { duration: data.duration, easing: identity });
  $$unsubscribe_progress = subscribe(progress, (value) => $progress = value);
  if ($$props.theme === void 0 && $$bindings.theme && theme !== void 0)
    $$bindings.theme(theme);
  if ($$props.data === void 0 && $$bindings.data && data !== void 0)
    $$bindings.data(data);
  $$result.css.add(css);
  $$unsubscribe_progress();
  return `<div class="${"st-toast flat " + escape(data.theme || theme, true) + " " + escape(data.type || "info", true) + " svelte-uiy59d"}" role="alert" aria-live="assertive" aria-atomic="true">${slots.icon ? slots.icon({}) : ` ${data.type === "success" ? `<svg class="st-toast-icon svelte-uiy59d" xmlns="http://www.w3.org/2000/svg" width="20" height="20" viewBox="0 0 20 20" aria-hidden="true"><path d="M10,1c-4.9,0-9,4.1-9,9s4.1,9,9,9s9-4,9-9S15,1,10,1z M8.7,13.5l-3.2-3.2l1-1l2.2,2.2l4.8-4.8l1,1L8.7,13.5z"></path><path fill="none" d="M8.7,13.5l-3.2-3.2l1-1l2.2,2.2l4.8-4.8l1,1L8.7,13.5z" data-icon-path="inner-path" opacity="0"></path></svg>` : `${data.type === "info" ? `<svg class="st-toast-icon svelte-uiy59d" xmlns="http://www.w3.org/2000/svg" width="20" height="20" viewBox="0 0 32 32" aria-hidden="true"><path d="M16,2A14,14,0,1,0,30,16,14,14,0,0,0,16,2Zm0,5a1.5,1.5,0,1,1-1.5,1.5A1.5,1.5,0,0,1,16,7Zm4,17.12H12V21.88h2.88V15.12H13V12.88h4.13v9H20Z"></path></svg>` : `${data.type === "error" ? `<svg class="st-toast-icon svelte-uiy59d" xmlns="http://www.w3.org/2000/svg" width="20" height="20" viewBox="0 0 20 20" aria-hidden="true"><path d="M10,1c-5,0-9,4-9,9s4,9,9,9s9-4,9-9S15,1,10,1z M13.5,14.5l-8-8l1-1l8,8L13.5,14.5z"></path><path d="M13.5,14.5l-8-8l1-1l8,8L13.5,14.5z" data-icon-path="inner-path" opacity="0"></path></svg>` : `<svg class="st-toast-icon svelte-uiy59d" xmlns="http://www.w3.org/2000/svg" width="20" height="20" viewBox="0 0 20 20" aria-hidden="true"><path d="M10,1c-5,0-9,4-9,9s4,9,9,9s9-4,9-9S15,1,10,1z M9.2,5h1.5v7H9.2V5z M10,16c-0.6,0-1-0.4-1-1s0.4-1,1-1	s1,0.4,1,1S10.6,16,10,16z"></path><path d="M9.2,5h1.5v7H9.2V5z M10,16c-0.6,0-1-0.4-1-1s0.4-1,1-1s1,0.4,1,1S10.6,16,10,16z" data-icon-path="inner-path" opacity="0"></path></svg>`}`}`} `} <div class="st-toast-details svelte-uiy59d">${data.title ? `<h3 class="st-toast-title svelte-uiy59d">${escape(data.title)}</h3>` : ``} <p class="st-toast-description svelte-uiy59d">${escape(data.description)}</p> <div class="st-toast-extra">${slots.extra ? slots.extra({}) : ``}</div></div> <button class="st-toast-close-btn svelte-uiy59d" type="button" aria-label="close">${slots["close-icon"] ? slots["close-icon"]({}) : ` <svg xmlns="http://www.w3.org/2000/svg" class="bx--toast-notification__close-icon svelte-uiy59d" width="20" height="20" viewBox="0 0 32 32" aria-hidden="true"><path d="M24 9.4L22.6 8 16 14.6 9.4 8 8 9.4 14.6 16 8 22.6 9.4 24 16 17.4 22.6 24 24 22.6 17.4 16 24 9.4z"></path></svg> `}</button> ${data.showProgress ? `<progress style="${"height: " + escape(data.duration > 0 ? "4px" : 0, true)}"${add_attribute("value", $progress, 0)} class="svelte-uiy59d"></progress>` : ``} </div>`;
});
const Page = create_ssr_component(($$result, $$props, $$bindings, slots) => {
  let $userData, $$unsubscribe_userData;
  $$unsubscribe_userData = subscribe(userData, (value) => $userData = value);
  let { data } = $$props;
  if ($$props.data === void 0 && $$bindings.data && data !== void 0)
    $$bindings.data(data);
  $$unsubscribe_userData();
  return `${$$result.head += `<!-- HEAD_svelte-15ur07d_START -->${$$result.title = `<title>@${escape(data.username)} Links</title>`, ""}<meta name="description" content="${"=" + escape(data.bio, true)}"><!-- HEAD_svelte-15ur07d_END -->`, ""} <main class="prose text-center mx-auto mt-8"><h1 class="text-4xl text-teal-700">@${escape(data.username)}</h1> <img${add_attribute("src", data.photoURL ?? "/user.png", 0)} alt="photoURL" width="128" class="mx-auto rounded-2xl mt-8"> <p class="text-xl mx-auto my-8 whitespace-pre-line">${escape(data.bio ?? "no bio yet...")}</p></main> <div class="mx-auto"><ul class="list-none min-w-96">${each(data.links, (item) => {
    return `<div class="my-2">${validate_component(UserLink, "UserLink").$$render($$result, Object.assign({}, item), {}, {})} </div>`;
  })}</ul> <br></div> ${$userData?.username == data.username ? `<div class="top-0 right-0 absolute"><a href="${"/" + escape($userData?.username, true) + "/edit"}"><button class="btn btn-ghost text-xs btn-xs mx-3 my-3" data-svelte-h="svelte-9jidyy">Edit Profile</button> <button class="btn btn-error text-xs btn-xs mx-3 my-3" data-svelte-h="svelte-1lurvw2">Sign Out</button></a></div> <div class="mx-auto"><button class="mx-auto btn btn-neutral" data-svelte-h="svelte-6ecr8p">share</button> ${validate_component(ToastContainer, "ToastContainer").$$render($$result, {}, {}, {
    default: ({ data: data2 }) => {
      return `${validate_component(FlatToast, "FlatToast").$$render($$result, { data: data2 }, {}, {})}`;
    }
  })}</div>` : `<div class="top-0 right-0 absolute"><button class="btn btn-success text-xs btn-xs mx-3 my-3" data-svelte-h="svelte-1qcmq0">Sign in</button></div>`}`;
});

export { Page as default };
//# sourceMappingURL=_page.svelte-RXWHGWbA.js.map
